@@ -2,7 +2,7 @@
 /**
  +-------------------------------------------------------------------------+
  | Roundcube Webmail IMAP Client                                           |
- | Version 1.5.0                                                           |
+ | Version 1.6.1                                                           |
  |                                                                         |
  | Copyright (C) The Roundcube Dev Team                                    |
  |                                                                         |
@@ -49,14 +49,9 @@ $RCMAIL->output->common_headers(!empty($_SESSION['user_id']));
 // turn on output buffering
 ob_start();
 
-// check if config files had errors
-if ($err_str = $RCMAIL->config->get_error()) {
-    rcmail::raise_error(['code' => 601, 'message' => $err_str], false, true);
-}
-
-// check DB connections and exit on failure
-if ($err_str = $RCMAIL->db->is_error()) {
-    rcmail::raise_error(['code' => 603, 'type' => 'db', 'message' => $err_str], false, true);
+// check the initial error state
+if ($RCMAIL->config->get_error() || $RCMAIL->db->is_error()) {
+    rcmail_fatal_error();
 }
 
 // error steps
@@ -102,7 +97,7 @@ $session_error = null;
 
 // try to log in
 if ($RCMAIL->task == 'login' && $RCMAIL->action == 'login') {
-    $request_valid = $_SESSION['temp'] && $RCMAIL->check_request();
+    $request_valid = !empty($_SESSION['temp']) && $RCMAIL->check_request();
     $pass_charset  = $RCMAIL->config->get('password_charset', 'UTF-8');
 
     // purge the session in case of new login when a session already exists
