@@ -49,6 +49,19 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $this->assertMatchesRegularExpression('|href="http://domain\.com"|', $washed, "Link href with no protocol (#7454)");
     }
 
+    /**
+     * Test data:image with newlines (#8613)
+     */
+    function test_data_image_with_newline()
+    {
+        $html = "<p><img src=\"data:image/png;base64,12345\n\t67890\" /></p>";
+
+        $washer = new rcube_washtml;
+        $washed = $washer->wash($html);
+
+        $this->assertSame("<p><img src=\"data:image/png;base64,12345\n\t67890\" /></p>", $this->cleanupResult($washed));
+    }
+
     /**
      * Test XSS in area's href (#5240)
      */
@@ -664,6 +677,13 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $this->assertStringContainsString('for="testmy-other-id"', $washed);
         $this->assertStringContainsString('href="#testmy-id"', $washed);
         $this->assertStringContainsString('class="testmy-class1 testmy-class2"', $washed);
+
+        // Make sure the anchor name is prefixed too
+        $html = '<p><a href="#a">test link</a></p><a name="a">test anchor</a>';
+        $washed = $washer->wash($html);
+
+        $this->assertStringContainsString('href="#testa"', $washed);
+        $this->assertStringContainsString('name="testa"', $washed);
     }
 
     /**
